'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _templateObject = _taggedTemplateLiteral(['\n  background: ', ';\n  border-radius: 4px;\n  border: 2px solid ', ';\n  color: ', ';\n  margin: 8px 0 8px 0;\n  min-height: 1em;\n  opacity: ', ';\n  padding: 1em;\n  transition: opacity 0.2s linear;\n'], ['\n  background: ', ';\n  border-radius: 4px;\n  border: 2px solid ', ';\n  color: ', ';\n  margin: 8px 0 8px 0;\n  min-height: 1em;\n  opacity: ', ';\n  padding: 1em;\n  transition: opacity 0.2s linear;\n']),
    _templateObject2 = _taggedTemplateLiteral(['\n  float: right;\n  cursor: pointer;\n  margin-left: 1em;\n'], ['\n  float: right;\n  cursor: pointer;\n  margin-left: 1em;\n']);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _styledComponents = require('styled-components');

var _styledComponents2 = _interopRequireDefault(_styledComponents);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _theme = require('../../utils/theme');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _taggedTemplateLiteral(strings, raw) { return Object.freeze(Object.defineProperties(strings, { raw: { value: Object.freeze(raw) } })); }

var StyledAlert = _styledComponents2.default.div(_templateObject, (0, _theme.fromAtoms)('Alert', 'type', 'background'), (0, _theme.fromAtoms)('Alert', 'type', 'borderColor'), (0, _theme.fromAtoms)('Alert', 'type', 'color'), function (props) {
  return props.visible ? '1' : '0';
});

var CloseIcon = _styledComponents2.default.i(_templateObject2);

/**
 * An alert to let the user know about an action or state.
 * ```javascript
 * import { Alert } from 'weaveworks-ui-components';
 *
 * export default function() {
 *  return (
 *    <div>
 *     <Alert type="warning" visible={true}>
 *       Warning: Hmm, this is not good, but its not terrible.
 *     </Alert>
 *    </div>
 *   )
 * }
 * ```
 */
function Alert(props) {
  var onClose = props.onClose,
      children = props.children;

  return _react2.default.createElement(
    StyledAlert,
    props,
    children,
    _react2.default.createElement(CloseIcon, { onClick: onClose, className: 'fa fa-remove' })
  );
}

Alert.propTypes = {
  /**
   * Set the color scheme to indicate the nature of the alert.
   */
  type: _propTypes2.default.oneOf(['default', 'success', 'warning', 'error']),

  /**
   * Toggle whether the alert is shown
   */
  visible: _propTypes2.default.bool,
  /**
   * Callback that runs with the alert is dismissed by clicking the 'X'
   */
  onClose: _propTypes2.default.func
};

Alert.defaultProps = {
  type: 'default',
  visible: true
};

exports.default = Alert;